@@ -1,5 +1,5 @@
 #
-#   Copyright (c) 2004-2013 Lincoln A. Baxter
+#   Copyright (c) 2004-2016 Lincoln A. Baxter
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file,
@@ -7,7 +7,7 @@
 package Sys::SigAction;
 require 5.005;
 use strict;
-#use warnings;
+use warnings;
 use POSIX qw( :signal_h ceil INT_MAX ) ;
 require Exporter;
 use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS );
@@ -29,7 +29,7 @@ sub sig_alarm
 
 @ISA = qw( Exporter );
 @EXPORT_OK = qw( set_sig_handler timeout_call sig_name sig_number sig_alarm );
-$VERSION = '0.20';
+$VERSION = '0.24';
 
 use Config;
 my %signame = ();
@@ -401,8 +401,10 @@ Since sigaction() is not fully functional in perl versions less than
 C<%SIG> array.  The version checking and implementation of the 'right'
 code is handled by this module, so the user does not have to write perl
 version dependent code.  The attrs hashref argument to set_sig_handler()
-is silently ignored, in perl versions less than 5.8.  This module has
-been tested with perls as old as 5.005 on solaris.
+is silently ignored, in perl versions less than 5.8.  When this module 
+was developed it was tested on perl 5.005 on solaris.  That was in 2004.
+Now only perl versions >= 5.6 are supported. If you want this to work on 
+perl 5.5 you will have comment out "use warnings" everywhere.
 
 It is hoped that with the use of this module, your signal handling
 behavior can be coded in a way that does not change from one perl version
@@ -535,8 +537,8 @@ Read the following from perldoc perlthrtut:
 That said, perl documentation for perl threading discusses a a way of
 emulating signals in multi-threaded applications, when safe signals
 is in effect. See perldoc threads and search for THREAD SIGNALLING.
-I have no test of multithreading and this module.  If you thing they
-could used compatibly, and would provide value, patches are welcome.
+I have no test of multithreading and this module.  If you think they
+could be used compatibly and would provide value, patches are welcome.
 
 =head1 AUTHOR
 
@@ -544,7 +546,7 @@ could used compatibly, and would provide value, patches are welcome.
 
 =head1 COPYRIGHT
 
-   Copyright (c) 2004-2013 Lincoln A. Baxter
+   Copyright (c) 2004-2016 Lincoln A. Baxter
    All rights reserved.
 
    You may distribute under the terms of either the GNU General Public
@@ -556,11 +558,4 @@ could used compatibly, and would provide value, patches are welcome.
    perldoc perlvar 
    perldoc POSIX
 
-=head NOTE
-
-Recent versions of DBD::Oracle no longer reference this module in the
-POD, so DBD::Oracle may now have solved the connection timeout problem
-internally. For older versions, the dbd-oracle-timeout.pod file provides
-a DBD-Oracle test script, which illustrates the use of this
-module with the DBD-Oracle driver.
 
